Runtime types and minimal runtime helpers for the Cosmos chain-registry schemas.
- Exact field names via serde rename
- Optional fields will use Option
in follow-up commits - Open-ended maps will use HashMap<String, serde_json::Value>
Structs
- Asset
- Asset
List - Binaries
- Chain
- Chain corresponds to chain.schema.json root object (initial pass: required fields only).
- Chain
Info - Chain
Version - Channel
- Channel
Info - Channel
Tags - Consensus
Info - Cosmwasm
Info - Denom
Unit - IbcData
- IbcInfo
- Language
Info - Logo
Uris - MemoKey
- Memo
Keys - Operator
- Operator
Info - SdkInfo
- Versions
Functions
- fetch_
asset_ list - Fetch an assetlist.json by chain name.
- fetch_
chain - Fetch a chain.json by chain name from the public registry. No caching or validation beyond JSON parsing.
- fetch_
ibc_ connection - Fetch IBC connection data for a pair of chains from _IBC/-.json (alphabetically sorted).
- fetch_
memo_ keys - Fetch memo_keys.json (root of registry). Name parameter kept for signature symmetry.
- fetch_
versions - Fetch versions.json by chain name.
- ibc_
connection_ url